"use strict";

module.exports = [
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'image\.png 480w 2x broken' at 'broken'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'image\.png broken' at 'broken'/,
	/Bad value for attribute "srcset" on element "img": Must contain one or more image candidate strings/,
	/Bad value for attribute "srcset" on element "img": Must contain one or more image candidate strings/,
	/Bad value for attribute "src" on element "img": Must be non-empty/,
	/Bad value for attribute "srcset" on element "img": Must contain one or more image candidate strings/,
	/Bad value for attribute "src" on element "img": Must be non-empty/,
	/Bad value for attribute "src" on element "img": Must be non-empty/,
	/Bad value for attribute "srcset" on element "img": Must contain one or more image candidate strings/,
	/Bad value for attribute "src" on element "img": Must be non-empty/,
	/Bad value for attribute "srcset" on element "img": Must contain one or more image candidate strings/,
	/Bad value for attribute "srcset" on element "img": Must contain one or more image candidate strings/,
	/Bad value for attribute "src" on element "img": Must be non-empty/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'image\.png 0h, image\.png 800w' at '0h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in ',a foo' at 'foo'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'a \(,' at '\(,'/,
	/Bad value for attribute "srcset" on element "img": Must contain one or more image candidate strings/,
	/Bad value for attribute "srcset" on element "img": Must contain one or more image candidate strings/,

	// TODO(html-entities): These regexes assert that numeric character references (e.g., `&#x9;`)
	// are NOT decoded by the HTML parser before being passed to the `srcset` parser.
	// If `HtmlParser.js` is ever updated to decode entities globally, these tests will
	// fail because `&#x9;` will become `\t` (whitespace) and successfully parse as a valid srcset.
	// Any future HTML decoding must be implemented selectively to preserve this behavior.
	/Can't resolve '&#x9;&#x9;data:,a&#x9;&#x9;1x&#x9;&#x9;'/,
	/Can't resolve '&#xA;&#xA;data:,a&#xA;&#xA;1x&#xA;&#xA;'/,
	/Can't resolve '&#xB;&#xB;data:,a&#xB;&#xB;1x&#xB;&#xB;'/,
	/Can't resolve '&#xC;&#xC;data:,a&#xC;&#xC;1x&#xC;&#xC;'/,
	/Can't resolve '&#xD;&#xD;data:,a&#xD;&#xD;1x&#xD;&#xD;'/,
	/Can't resolve '&#xE;&#xE;data:,a&#xE;&#xE;1x&#xE;&#xE;'/,
	/Can't resolve '&#xF;&#xF;data:,a&#xF;&#xF;1x&#xF;&#xF;'/,
	/Can't resolve '&#x10;&#x10;data:,a&#x10;&#x10;1x&#x10;&#x10;'/,
	/Can't resolve '&nbsp;data:,a'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a \( , data:,b 1x, \), data:,c' at '\( , data:,b 1x, \)'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a \(\(\( , data:,b 1x, \), data:,c' at '\(\(\( , data:,b 1x, \)'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a \[ , data:,b 1x, \], data:,c' at '\['/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a \{ , data:,b 1x, \}, data:,c' at '\{'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a, data:,b \(' at '\('/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a, data:,b \( {2}' at '\( {2}'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a, data:,b \(,' at '\(,'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a, data:,b \(x' at '\(x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a, data:,b \(\)' at '\(\)'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a \(, data:,b' at '\(, data:,b'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a \/\*, data:,b, data:,c \*\/' at '\/\*'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a \/\/, data:,b' at '\/\/'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a foo' at 'foo'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a foo foo' at 'foo'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a foo 1x' at '1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a foo 1x foo' at 'foo'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a foo 1w' at '1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a foo 1w foo' at 'foo'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1x 1x' at '1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1w' at '1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1h 1h' at '1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1x' at '1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1x 1w' at '1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1h 1x' at '1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1h 1w 1x' at '1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1x 1w 1h' at '1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1h foo' at 'foo'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a foo 1h' at '1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 0w' at '0w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a -1w' at '-1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w -1w' at '-1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1\.0w' at '1\.0w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1\.0w' at '1\.0w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1e0w' at '1e0w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1e0w' at '1e0w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1www' at '1www'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1www' at '1www'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w \+1w' at '\+1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1W' at '1W'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1W' at '1W'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a Infinityw' at 'Infinityw'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w Infinityw' at 'Infinityw'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a NaNw' at 'NaNw'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w NaNw' at 'NaNw'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 0x1w' at '0x1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x1;w' at '1&#x1;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&nbsp;w' at '1&nbsp;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x1680;w' at '1&#x1680;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2000;w' at '1&#x2000;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2001;w' at '1&#x2001;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2002;w' at '1&#x2002;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2003;w' at '1&#x2003;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2004;w' at '1&#x2004;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2005;w' at '1&#x2005;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2006;w' at '1&#x2006;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2007;w' at '1&#x2007;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2008;w' at '1&#x2008;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2009;w' at '1&#x2009;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x200A;w' at '1&#x200A;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x200C;w' at '1&#x200C;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x200D;w' at '1&#x200D;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x202F;w' at '1&#x202F;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x205F;w' at '1&#x205F;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x3000;w' at '1&#x3000;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#xFEFF;w' at '1&#xFEFF;w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x1;1w' at '&#x1;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &nbsp;1w' at '&nbsp;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x1680;1w' at '&#x1680;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2000;1w' at '&#x2000;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2001;1w' at '&#x2001;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2002;1w' at '&#x2002;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2003;1w' at '&#x2003;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2004;1w' at '&#x2004;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2005;1w' at '&#x2005;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2006;1w' at '&#x2006;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2007;1w' at '&#x2007;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2008;1w' at '&#x2008;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2009;1w' at '&#x2009;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x200A;1w' at '&#x200A;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x200C;1w' at '&#x200C;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x200D;1w' at '&#x200D;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x202F;1w' at '&#x202F;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x205F;1w' at '&#x205F;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x3000;1w' at '&#x3000;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#xFEFF;1w' at '&#xFEFF;1w'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1x -0x' at '-0x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a -1x' at '-1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1x -1x' at '-1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a -x' at '-x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a \.x' at '\.x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a -\.x' at '-\.x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1\.x' at '1\.x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1x 1\.5e1x' at '1\.5e1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1x 1e1\.5x' at '1e1\.5x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1x 1\.0x' at '1\.0x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a \+1x' at '\+1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1X' at '1X'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a Infinityx' at 'Infinityx'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a NaNx' at 'NaNx'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 0x1x' at '0x1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 0X1x' at '0X1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x1;x' at '1&#x1;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&nbsp;x' at '1&nbsp;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x1680;x' at '1&#x1680;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2000;x' at '1&#x2000;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2001;x' at '1&#x2001;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2002;x' at '1&#x2002;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2003;x' at '1&#x2003;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2004;x' at '1&#x2004;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2005;x' at '1&#x2005;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2006;x' at '1&#x2006;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2007;x' at '1&#x2007;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2008;x' at '1&#x2008;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x2009;x' at '1&#x2009;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x200A;x' at '1&#x200A;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x200C;x' at '1&#x200C;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x200D;x' at '1&#x200D;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x202F;x' at '1&#x202F;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x205F;x' at '1&#x205F;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#x3000;x' at '1&#x3000;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1&#xFEFF;x' at '1&#xFEFF;x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x1;1x' at '&#x1;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &nbsp;1x' at '&nbsp;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x1680;1x' at '&#x1680;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2000;1x' at '&#x2000;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2001;1x' at '&#x2001;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2002;1x' at '&#x2002;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2003;1x' at '&#x2003;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2004;1x' at '&#x2004;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2005;1x' at '&#x2005;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2006;1x' at '&#x2006;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2007;1x' at '&#x2007;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2008;1x' at '&#x2008;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x2009;1x' at '&#x2009;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x200A;1x' at '&#x200A;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x200C;1x' at '&#x200C;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x200D;1x' at '&#x200D;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x202F;1x' at '&#x202F;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x205F;1x' at '&#x205F;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#x3000;1x' at '&#x3000;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a &#xFEFF;1x' at '&#xFEFF;1x'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 0h' at '0h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w -1h' at '-1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1\.0h' at '1\.0h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1e0h' at '1e0h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1hhh' at '1hhh'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1H' at '1H'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w Infinityh' at 'Infinityh'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w NaNh' at 'NaNh'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 0x1h' at '0x1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 0X1h' at '0X1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x1;h' at '1&#x1;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&nbsp;h' at '1&nbsp;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x1680;h' at '1&#x1680;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x2000;h' at '1&#x2000;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x2001;h' at '1&#x2001;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x2002;h' at '1&#x2002;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x2003;h' at '1&#x2003;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x2004;h' at '1&#x2004;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x2005;h' at '1&#x2005;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x2006;h' at '1&#x2006;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x2007;h' at '1&#x2007;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x2008;h' at '1&#x2008;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x2009;h' at '1&#x2009;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x200A;h' at '1&#x200A;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x200C;h' at '1&#x200C;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x200D;h' at '1&#x200D;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x202F;h' at '1&#x202F;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x205F;h' at '1&#x205F;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#x3000;h' at '1&#x3000;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w 1&#xFEFF;h' at '1&#xFEFF;h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x1;1h' at '&#x1;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &nbsp;1h' at '&nbsp;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x1680;1h' at '&#x1680;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x2000;1h' at '&#x2000;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x2001;1h' at '&#x2001;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x2002;1h' at '&#x2002;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x2003;1h' at '&#x2003;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x2004;1h' at '&#x2004;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x2005;1h' at '&#x2005;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x2006;1h' at '&#x2006;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x2007;1h' at '&#x2007;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x2008;1h' at '&#x2008;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x2009;1h' at '&#x2009;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x200A;1h' at '&#x200A;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x200C;1h' at '&#x200C;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x200D;1h' at '&#x200D;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x202F;1h' at '&#x202F;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x205F;1h' at '&#x205F;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#x3000;1h' at '&#x3000;1h'/,
	/Bad value for attribute "srcset" on element "img": Invalid srcset descriptor found in 'data:,a 1w &#xFEFF;1h' at '&#xFEFF;1h'/,
	/Bad value for attribute "srcset" on element "img": Must contain one or more image candidate strings/,
	/Bad value for attribute "srcset" on element "img": Must contain one or more image candidate strings/
];
